/**
 *******************************************************************************
 * @file    tmpm341_ofd.h
 * @brief   This file provides all the functions prototypes for OFD driver.
 * @version V2.0.2.3
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM341_OFD_H
#define __TMPM341_OFD_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM341.h"
#include "tx03_common.h"

/* #define LITTLE_ENDIAN */

#if defined(__TMPM341_OFD_H)
/** @addtogroup TX03_Periph_Driver
  * @{
  */
/** @addtogroup OFD
  * @{
  */
/** @addtogroup OFD_Exported_Types
  * @{
  */
#ifdef LITTLE_ENDIAN
    typedef union {
        uint32_t All;
        struct {
            uint32_t FrequencyError:1;
            uint32_t OFDBusy:1;
            uint32_t Reserved:30;
        } Bit;
    } OFD_Status;
#else
    typedef union {
        uint32_t All;
        struct {
            uint32_t Reserved:30;
            uint32_t OFDBusy:1;
            uint32_t FrequencyError:1;
        } Bit;
    } OFD_Status;
#endif
/** @} */
/* End of group OFD_Exported_Types */

/** @defgroup OFD_Exported_FunctionPrototypes
  * @{
  */
    void OFD_SetRegWriteMode(FunctionalState NewState);
    void OFD_Enable(void);
    void OFD_Disable(void);
    void OFD_SetDetectionFrequency(uint16_t HigherDetectionCount, uint16_t LowerDetectionCount);
    void OFD_Reset(FunctionalState NewState);
    OFD_Status OFD_GetStatus(void);
/** @} */
/* End of group OFD_Exported_FunctionPrototypes */
/** @} */
/* End of group OFD */
/** @} */
/* End of group TX03_Periph_Driver */
#endif                          /* defined(__TMPM341_OFD_H) */
#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* (__TMPM341_OFD_H) */
