/**
 *******************************************************************************
 * @file    tmpm341_phc.h
 * @brief   This file provides all the functions prototypes for PHC driver. 
 * @version V2.0.2.2
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __TMPM341_PHC_H
#define __TMPM341_PHC_H

#ifdef __cplusplus
extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "TMPM341.h"
#include "tx03_common.h"

/* #define LITTLE_ENDIAN */
/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @addtogroup PHC
  * @{
  */

/** @defgroup PHC_Exported_Types
  * @{
  */

/**
  * @brief PHC Init Structure definition
  */

    typedef struct {
        uint32_t Mode;          /*!< Select PHC mode among normal mode, Quadruple mode, and Multiplied by two mode */
        uint32_t NoiseFilterCtrl;       /*!< Select PHC noise filter control */
        uint32_t CountClearCtrl;        /*!< Select PHC counter clear control */
    } PHC_InitTypeDef;

/**
  * @brief PHC Interrupt factor Union definition
  */
#ifdef LITTLE_ENDIAN
    typedef union {
        uint32_t All;
        struct {
            uint32_t Compare0:1;
            uint32_t Compare1:1;
            uint32_t OverFlow:1;
            uint32_t UnderFlow:1;
            uint32_t Reserverd:28;
        } Bit;
    } PHC_INTFactor;
#else
    typedef union {
        uint32_t All;
        struct {
            uint32_t Reserverd:28;
            uint32_t UnderFlow:1;
            uint32_t OverFlow:1;
            uint32_t Compare1:1;
            uint32_t Compare0:1;
        } Bit;
    } PHC_INTFactor;
#endif
/** @} */
/* End of group PHC_Exported_Types */

/** @defgroup PHC_Exported_Constants
  * @{
  */

#define IS_PHC_ALL_PERIPH(param)        (((param) == TSB_PHC0) || \
                                         ((param) == TSB_PHC1) || \
                                         ((param) == TSB_PHC2) || \
                                         ((param) == TSB_PHC3))


/* <PHCxCR> */
#define PHC_CR_MODE_NORMAL              ((uint32_t)0x00000000)
#define PHC_CR_MODE_4TIMES              ((uint32_t)0x00000001)
#define PHC_CR_MODE_2TIMES_IN0          ((uint32_t)0x00000002)
#define PHC_CR_MODE_2TIMES_IN1          ((uint32_t)0x00000003)
#define IS_PHC_CR_MODE(param)           (((param) == PHC_CR_MODE_NORMAL) || \
                                         ((param) == PHC_CR_MODE_4TIMES) || \
                                         ((param) == PHC_CR_MODE_2TIMES_IN0) || \
                                         ((param) == PHC_CR_MODE_2TIMES_IN1))

#define PHC_CR_NOISEFILTER_ON           ((uint32_t)0x00000000)
#define PHC_CR_NOISEFILTER_OFF          ((uint32_t)0x00000004)
#define IS_PHC_CR_NOISEFILTER(param)    (((param) == PHC_CR_NOISEFILTER_OFF) || \
                                         ((param) == PHC_CR_NOISEFILTER_ON))

#define PHC_CR_INT_COMP0                ((uint32_t)0x00000008)
#define PHC_CR_INT_COMP1                ((uint32_t)0x00000010)
#define PHC_CR_INT_COMP0_AND_1          (PHC_CR_INT_COMP0 | PHC_CR_INT_COMP1)
#define PHC_CR_INT_EVERY                ((uint32_t)0x00000020)
#define PHC_CR_INT_ALL                  (PHC_CR_INT_EVERY | PHC_CR_INT_COMP0_AND_1)
#define IS_PHC_INT_ENABLE(param)        (((param) >= PHC_CR_INT_COMP0) && ((param) <= PHC_CR_INT_ALL))
#define IS_PHC_INT_DISABLE              IS_PHC_INT_ENABLE


/* <PHCxRUN> */
#define PHC_RUN                         ((uint32_t)0x00000001)
#define PHC_STOP                        ((uint32_t)0x00000000)
#define IS_PHC_CMD(param)               (((param) == PHC_RUN) || ((param) == PHC_STOP))

#define PHC_COUNT_CONTINUE              ((uint32_t)0x00000000)
#define PHC_COUNT_CLR                   ((uint32_t)0x00000002)
#define IS_PHC_COUNT_CTRL(param)        (((param) == PHC_COUNT_CONTINUE) || ((param) == PHC_COUNT_CLR))


/* <PHCxFLG> */
#define PHC_FLG_CMP0                    ((uint32_t)0x00000001)
#define PHC_FLG_CMP1                    ((uint32_t)0x00000002)
#define PHC_FLG_OVERFLOW                ((uint32_t)0x00000004)
#define PHC_FLG_UNDERFLOW               ((uint32_t)0x00000008)
#define PHC_FLG_ALL                     (PHC_FLG_CMP0 | \
                                         PHC_FLG_CMP1 | \
                                         PHC_FLG_OVERFLOW | \
                                         PHC_FLG_UNDERFLOW)

#define IS_PHC_FLG(param)               (((param) >= PHC_FLG_CMP0) && ((param) <= PHC_FLG_ALL))


/* <PHCxCMP0, PHCxCMP1> */
#define IS_PHC_CMP_VALUE(param)         ((param) <= 0x0000FFFFU)

#define PHC_COMP_0                      ((uint8_t)0x00)
#define PHC_COMP_1                      ((uint8_t)0x01)
#define IS_PHC_COMP_REG(param)          (((param) == PHC_COMP_0) || ((param) == PHC_COMP_1))


/* <PHCxCNT> */


/* <PHCxDMA> */
#define PHC_DMA_REQ_CAPTURE_2           ((uint32_t)0x000000004)
#define IS_PHC_DMA_REQ(param)           ((param) == PHC_DMA_REQ_CAPTURE_2)


/** @} */
/* End of PHC_Exported_Constants */

/** @defgroup PHC_Exported_FunctionPrototypes
  * @{
  */
    void PHC_Enable(TSB_PHC_TypeDef * PHCx);
    void PHC_Disable(TSB_PHC_TypeDef * PHCx);
    void PHC_SetRunState(TSB_PHC_TypeDef * PHCx, uint32_t Cmd);
    void PHC_Init(TSB_PHC_TypeDef * PHCx, PHC_InitTypeDef * InitStruct);
    PHC_INTFactor PHC_GetINTFactor(TSB_PHC_TypeDef * PHCx);
    void PHC_ClearINTFactor(TSB_PHC_TypeDef * PHCx, uint32_t ClearINT);
    void PHC_EnableInterrupt(TSB_PHC_TypeDef * PHCx, uint32_t EnableINT);
    void PHC_DisableInterrupt(TSB_PHC_TypeDef * PHCx, uint32_t DisableINT);
    uint16_t PHC_GetPulseCntValue(TSB_PHC_TypeDef * PHCx);
    void PHC_ClearPulseCntValue(TSB_PHC_TypeDef * PHCx);
    uint16_t PHC_GetCompareValue(TSB_PHC_TypeDef * PHCx, uint8_t CmpReg);
    void PHC_SetCompareValue(TSB_PHC_TypeDef * PHCx, uint8_t CmpReg, uint16_t CmpValue);
    void PHC_SetDMAReq(TSB_PHC_TypeDef * PHCx, FunctionalState NewState, uint8_t DMAReq);
/** @} */
/* End of PHC_Exported_FunctionPrototypes */

/** @} */
/* End of group PHC */

/** @} */
/* End of group TX03_Periph_Driver */
#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __TMPM341_PHC_H */
