/**
 *******************************************************************************
 * @file    tmpm341_dac.c
 * @brief   This file provides API functions for DAC driver.
 * @version V2.0.2.2
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm341_dac.h"


/** @addtogroup TX03_Periph_Driver
  * @{
  */

/** @defgroup DAC 
  * @brief DAC driver modules
  * @{
  */
/** @defgroup DAC_Private_Defines
  * @{
  */

#define DAC_START           ((uint32_t)0x00000003)
#define DAC_STOP            ((uint32_t)0x00000000)

/** @} */
/* End of group DAC_Private_Defines */

/** @defgroup DAC_Private_FunctionPrototypes
  * @{
  */

/** @} */
/* End of group DAC_Private_FunctionPrototypes */

/** @defgroup DAC_Private_Functions
  * @{
  */

/** @} */
/* End of group group DAC_Private_Functions */

/** @defgroup DAC_Exported_Functions
  * @{
  */

/**
  * @brief  Set DACx output code.
  * @param  DACx: Select the DAC channel.
  *         This parameter can be one of the following values:
  *         TSB_DA0, TSB_DA1
  *         OutputCode: output code (10 bit) which will be converted to analog data. 
  *         Max value of this parameter can be 0x03FF
  * @retval None
  */
void DAC_SetOutputCode(TSB_DA_TypeDef * DACx, uint16_t OutputCode)
{
    /* Check the parameters */
    assert_param(IS_DAC_CHANNEL(DACx));
    assert_param(IS_DAC_OUTPUT_CODE(OutputCode));

    /* Set DAC Output Code */
    DACx->REG = (uint32_t) OutputCode;
}

/**
  * @brief  Start the operation of the specified DAC channel.
  * @param  DACx: Select the DAC channel.
  *         This parameter can be one of the following values:
  *         TSB_DA0, TSB_DA1
  * @retval None
  */
void DAC_Start(TSB_DA_TypeDef * DACx)
{
    assert_param(IS_DAC_CHANNEL(DACx));
    DACx->CTL1 = DAC_START;
}

/**
  * @brief  Stop the operation of the specified DAC channel.
  * @param  DACx: Select the DAC channel.
  *         This parameter can be one of the following values:
  *         TSB_DA0, TSB_DA1
  * @retval None
  */
void DAC_Stop(TSB_DA_TypeDef * DACx)
{
    assert_param(IS_DAC_CHANNEL(DACx));
    DACx->CTL1 = DAC_STOP;
}



/** @} */
/* End of group DAC_Exported_Functions */

/** @} */
/* End of group DAC */

/** @} */
/* End of group TX03_Periph_Driver */
