/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of ADC_Data_Read demo for the TOSHIBA
 *          'TMPM341' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */
 
 
/*  ------------------- info -----------------------------------
    This is a simple ADC demo run on IAR TMPM341-SK board. 
    It will send the digit value of position of VR1 through UART0(115.2K, 8bit, no parity, 1 stop).

    To compile and run in LITTLE endian mode:
      1. uncomment the line  "#define LITTLE_ENDIAN" in tmpm341_adc.h
      2. in EWARM, select project option, then select General Options -> Target , select Endian mode as Little
      3. in TMPM341-SK board, disconncet JP2, disconncet E_JP4, connect E_JP41.

    To compile and run in BIG endian mode:
      1. comment the line  "#define LITTLE_ENDIAN" in tmpm341_adc.h
      2. in EWARM, select project option, then select General Options -> Target , select Endian mode as Big
      3. in TMPM341-SK board, disconncet JP2, connect E_JP4 , disconncet E_JP41.
      
        
    Backgroud knowledge:
    TMPM341 support big endian and little endian.
    When the BOOT pin(pin F2) is '1', the chip will enter 'Single chip mode' after reset,
      it will starts up from the internal flash memory which contain user's program.
      In this mode, the function of ENDIAN pin (pin A1)are:
          ENDIAN pin is '0': it will run in little endian mode after reset.
          ENDIAN pin is '1': it will run in big endian mode after reset.
    
    When the BOOT pin(pin F2) is '0', the chip will enter 'Single boot mode' after reset,
      it will starts up from the internal Boot ROM (Mask ROM). 
      In this mode, the function of ENDIAN pin is neglected and the chip always run in little endian mode.   

-------------------------------------------------------------- */
      
/* Includes ------------------------------------------------------------------*/
#include "main.h"

/**
  * @brief  main function
  * @param  None
  * @retval None
  */
int main(void)
{
    /* Initialize system */
    SIO_Configuration(UART0);
    SIO_ChInit();
    
    ADC_Init();                 /* Initialize the ADC module */
    ADC_Start();                /* Start ADC */
    
    /* enable SIO0 trx interrupt */
    NVIC_EnableIRQ(INTTX0_IRQn);
    /* enable AD interrupt */
    NVIC_EnableIRQ(INTAD_IRQn);

    while (1) {
        if (fIntADC == 1U) {
            fIntADC = 0U;
            ADC_Display();
        }
    }
}

/**
  * @brief  Deal with the error parameter
  * @param  file: Pointer to the file where the error parameter locates
  * @param  line: Number of the line in which the error parameter locates
  * @retval None
  */
#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
