/**
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of PHC demo for the TOSHIBA
 *          'TMPM341' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "tmpm341_gpio.h"
#include "tmpm341_wdt.h"
#include "tmpm341_phc.h"

/* Private typedef -----------------------------------------------------------*/

/* Private define ------------------------------------------------------------*/
#define PHC_DEBUG
/* Private macro -------------------------------------------------------------*/

/* Private variables ---------------------------------------------------------*/
volatile uint16_t count_result[100] = {0U};
volatile uint32_t count_num = 0;

/* external variables --------------------------------------------------------*/

/* Private function prototypes -----------------------------------------------*/

/*******************************************************************************
* Function Name  : App_PHCNT_Init
* Description    : Initialize phase counter
* Input          : None.
* Return         : None.
*******************************************************************************/
void App_PHCNT_Init(void)
{
    PHC_InitTypeDef InitStruct;

    /* PJ0/PJ1 PHC0IN0/PHC0IN1 setting */
    GPIO_SetInput(GPIO_PJ, (GPIO_BIT_1 | GPIO_BIT_0));
    GPIO_SetOutput(GPIO_PJ, (GPIO_BIT_2 | GPIO_BIT_3));
    GPIO_EnableFuncReg(GPIO_PJ, GPIO_FUNC_REG_3, (GPIO_BIT_1 | GPIO_BIT_0));
    GPIO_DisableFuncReg(GPIO_PJ, GPIO_FUNC_REG_3, (GPIO_BIT_2 | GPIO_BIT_3));
    GPIO_SetInputEnableReg(GPIO_PJ, (GPIO_BIT_1 | GPIO_BIT_0), ENABLE);
    GPIO_SetOutputEnableReg(GPIO_PJ, (GPIO_BIT_2 | GPIO_BIT_3), ENABLE);
    
    InitStruct.Mode = PHC_CR_MODE_4TIMES;                /* Quadruple mode */
    InitStruct.NoiseFilterCtrl = PHC_CR_NOISEFILTER_ON;  /* Noise Filter on */
    InitStruct.CountClearCtrl = PHC_COUNT_CLR;           /* Clear counter */
    
    PHC_Enable(TSB_PHC0);                            /* Enable PHC Operation */
    PHC_Init(TSB_PHC0, &InitStruct);                 /* Set InitStruct to PHC */
    PHC_DisableInterrupt(TSB_PHC0, PHC_CR_INT_ALL);  /* Disable all interrupt */
    PHC_EnableInterrupt(TSB_PHC0,PHC_CR_INT_EVERY);  /* Enable INTPHEVRY0 interrupt */
    NVIC_EnableIRQ(INTPHEVRY0_IRQn);                 
    PHC_SetRunState(TSB_PHC0, PHC_RUN);              /* Run PHC0 */
}

/*******************************************************************************
* Function Name  : App_PHCNT_Monitor
* Description    : Monitor the phase counter
* Input          : None.
* Return         : None.
*******************************************************************************/
void delay(void)
{
  uint32_t i;
  for(i = 0; i<10; i++);
}
int main(void)
{    
    uint32_t i;
    
    App_PHCNT_Init();
    
    for(i = 0; i < 10; i++)
    {
      /* Generate Input */
      /* PJ2(output) -> PHC0IN0 (J1 pin3 <-> J1 pin5) */
      /* PJ3(output) -> PHC0IN1 (J1 pin4 <-> J1 pin6) */
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_1);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_0);
      delay();
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_1);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_1);
      delay();
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_0);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_1);
      delay();
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_0);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_0);
      delay();
    }
    for(i = 0; i < 10; i++)
    {
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_0);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_1);
      delay();
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_1);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_1);
      delay();
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_1);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_0);
      delay();
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_2,GPIO_BIT_VALUE_0);
      GPIO_WriteDataBit(GPIO_PJ, GPIO_BIT_3,GPIO_BIT_VALUE_0);
      delay();
    }
    while(1);
}

void INTPHEVRY0_IRQHandler(void)
{
    if(count_num <= 100) {          /* Judge if overflow count_result[] or not */
        count_result[count_num++] = PHC_GetPulseCntValue(TSB_PHC0);/* get count value */
    } else {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif

