/** 
 *******************************************************************************
 * @file    main.c
 * @brief   The application functions of TMRD interval timer demo for the TOSHIBA
 *          'TMPM341' Device Series 
 * @version V0.101
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

#include "tmpm341_tmrd.h"
#include "tmpm341_cg.h"
#include "led.h"

/* fosc = 10MHz(external high-speed oscillator)
 * fpll = 8 * fosc = 80MHz(in this demo, PLL multiplying value is set to 8 multiplying)
 * ftmrd = fpll = 80MHz(in this demo, ftmrd = fpll, please see CG_SetFtmrdSrc())
 * So the value of TIME_500US is 500us*ftmrd = 40000 = 0x9C40
 */
#define TIME_500US    ((uint16_t)0x9C40U)

int main(void)
{
    LEDInit();

    /* TMRD CG setting */
    CG_SetFtmrdSrc(CG_FTMRD_SRC_FPLL);
    CG_SetTMRDClk(ENABLE);

    /* TMRD mode setting */
    TMRD_SetMode(TMRD_MODE_BOTH_TMR);

    /* TMRD IDLE mode */
    TMRD_SetRunStateInIdle(TSB_TD0, TMRD_RUN);

    /* TMRD enable clock signal */
    TMRD_Enable(TSB_TD0);

    /* Set the TMRD prescaler */
    TMRD_SetClkDivision(TSB_TD0, TMRD_CLK_DIV_1);

    /* Set the upcounter clear mode */
    TMRD_SetUpCntCtrl(TSB_TD0, TMRD_AUTO_CLEAR);

    /* Direct update the compare register */
    TMRD_SetCMPRegWritePath(TSB_TD0, TMRD_CMP_WRITE_DIRECT);

    /* Set the value to timer register */
    TMRD_ChangeTiming(TMRD_TIMING_TD0_CYCLE, TIME_500US);       /* 500us */

    /* Indirct update the compare register */
    TMRD_SetCMPRegWritePath(TSB_TD0, TMRD_CMP_WRITE_INDIRECT);

    /* Enable TMRD intterrupt */
    TMRD_SetCMP0INTSrc(TSB_TD0, TMRD_INT_MATCH_CYCLE);

    NVIC_EnableIRQ(INTTD0CMP0_IRQn);

    /* Start to run TMRD */
    TMRD_SetRunState(TSB_TD0, TMRD_RUN);

    while (1) {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
        __NOP();
    }
}
#endif
