/**
 ******************************************************************************
 * @file     led.c
 * @brief    LED driver for the TOSHIBA 'TMPM341' Device Series
 * @version  V0.101
 * @date     2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 ******************************************************************************
 */

/** include files **/

#include "led.h"
#include "tmpm341_gpio.h"
/** local definitions **/

/** default settings **/

/** external functions **/

/** external data **/

/** internal functions **/

/** private data **/

/** public functions **/
/**
  * @brief  delay some time
  * @param  delay time
  * @retval None.
  */
void delay(uint32_t time)
{
    uint32_t i;
    for (i = 0U; i < time; i++) {
        /* Do nothing */
    }
}

/*************************************************************************
 * Function Name: LED_Init
 * Parameters:None
 *
 * Return:None  
 *
 * Description: Init LED ports
 *
 *************************************************************************/
void LEDInit(void)
{
#ifdef M341_SK_BOARD
    GPIO_SetOutput(LED_DATA_PORT, 0x04U);
    GPIO_WriteData(LED_DATA_PORT, 0x04U);
#else
    GPIO_SetOutput(LED_DATA_PORT, 0x0FU);
    GPIO_WriteData(LED_DATA_PORT, 0x0FU);
#endif
}

/*************************************************************************
 * Function Name: LedOff
 * Parameters:LED number
 *
 * Return:None  
 *
 * Description: Led Digtit OFF, but others don't change
 *
 *************************************************************************/
void LedOff(uint8_t led)
{
#ifdef M341_SK_BOARD
    GPIO_WriteDataBit(LED_DATA_PORT, GPIO_BIT_2, 0U);
#else
    uint8_t reg;
    reg = GPIO_ReadData(LED_DATA_PORT);
    reg &= (~led);
    GPIO_WriteData(LED_DATA_PORT, reg);
#endif
}

/*************************************************************************
 * Function Name: LedOn
 * Parameters:LED number
 *
 * Return:None  
 *
 * Description: Led Digtit ON, but others don't change
 *
 *************************************************************************/
void LedOn(uint8_t led)
{
    GPIO_WriteData(LED_DATA_PORT, led);
}
